<template>
  <div class="app-container">
    <el-container>
      <el-container>
        <el-card class="box-card" style="width: 100%" shadow="never">
          <!--搜索条件-->
          <div class="filter-container">
            <my-search ref="searchBar" :items="items" @search="fifterForm"></my-search>
          </div>
          <el-row style="margin-top: 15px">
            <el-col>
              <!--列表-->
              <my-table-v2 ref="myTable" :filter="filterFrom" :table="table" />
            </el-col>
          </el-row>
        </el-card>
      </el-container>
    </el-container>
  </div>
</template>

<script>
import MyTableV2 from '@/components/myTable/myTableV2';
import MyButton from '@/components/myButton/myButton';
import SettingIplatform from '@/utils/settingIplatform';
import * as finsystenant from '@/api/baseSetting/finsystenant';
import { getBaseUrl } from '@/utils/base';
import { mapGetters } from 'vuex';
import { selectTenantWarehouse,goodsModel } from '@/api/baseSetting/finsystenant';
import { getDicts } from '@/api/system/dict/data';

export default {
  name: 'index',
  components: { MyButton, MyTableV2 },
  data() {
    return {
      // 搜索框
      items: [
        {
          type: 'cascader',
          dataIndex: 'agencyId',
          label: '机构',
          placeholder: '请选择',
          optionsConfig: { url: '/pc/fin/sys/tenant/select/tree_fin_tenant', props: null },
          defaultValue: '',
          options: [],
        },
        {
          type: 'select',
          dataIndex: 'warehouseId',
          label: '盘点仓库',
          placeholder: '请选择',
          defaultValue: '',
          options: [],
        },
        {
          type: 'text',
          dataIndex: 'name',
          label: '物品名称',
          placeholder: '请输入',
          defaultValue: '',
        },
        {
          type: 'select',
          dataIndex: 'warehouseId',
          label: '规格型号',
          placeholder: '请选择',
          defaultValue: '',
          options: [],
        },
        {
          type: 'select',
          dataIndex: 'warehouseId',
          label: '类型',
          placeholder: '请选择',
          defaultValue: '',
          options: [{
            label:'全部',
            value:''
          },{
            label:'盘盈',
            value:'1'
          },{
            label:'盘亏',
            value:'2'
          }],
        },
        {
          type: 'select',
          dataIndex: 'warehouseId',
          label: '出入库类型',
          placeholder: '请选择',
          defaultValue: '',
          options: [{
            label:'全部',
            value:''
          },{
            label:'盘盈入库',
            value:'1'
          },{
            label:'盘亏出库',
            value:'2'
          }],
        },
        {
          type: 'text',
          dataIndex: 'name',
          label: '单号',
          placeholder: '请输入',
          defaultValue: '',
        },
        {
          type: 'text',
          dataIndex: 'name',
          label: '操作人',
          placeholder: '请输入',
          defaultValue: '',
        },
        {
          type: 'date-picker',
          dataIndex: 'incomeTimeStart',
          label: '时间',
          defaultValue: '',
        },
        {
          type: 'date-picker',
          dataIndex: 'incomeTimeEnd',
          label: '至',
          defaultValue: '',
        },
      ],
      // 树数据
      treeDataList: [],
      // 搜索条件
      filterFrom: {
        tenantId: null,
        userName: null,
        userPhone: null,
        status: 1,
      },
      // 表格数据
      table: {
        showIndex: true, // 是否显示序号
        expand: false, // 是否显示详情数据
        url: SettingIplatform.apiBaseURL + '/pc/l/wh/form/inventory/list/PdDetail', // 请求地址
        // 工具条
        tools: {
          columnsCtrl: {
            // 列控制按钮
            show: false,
          },
          generalExport: {
            // 通用导出按钮
            show: false,
          },
          // 自定义工具条按钮
          custom: [],
        },
        // 列信息
        columns: [
          { title: '仓库', field: 'name', align: 'left' },
          { title: '物品名称', field: 'WAREHOUSE_NAME', align: 'center' },
          { title: '规格型号', field: 'lv', align: 'center' },
          { title: '类型', field: 'lv', align: 'center' },
          { title: '库存数量', field: 'summary', align: 'left' },
          { title: '盘点数量', field: 'summary', align: 'left' },
          { title: '异常数量', field: 'summary', align: 'left' },
          { title: '出入库类型', field: 'summary', align: 'left' },
          { title: '出入库单号', field: 'summary', align: 'left' },
          { title: '机构', field: 'summary', align: 'left' },
          { title: '操作人', field: 'summary', align: 'left' },
          { title: '操作时间', field: 'summary', align: 'left' },
        ],
        // 操作信息
        operation: {
          show: false, // 显示操作列
          width: '150', // 列宽
          attr: [],
        },
        paging: {
          show: true, // 显示分页
          // 分页信息
          page: {
            small: false,
            pageNum: 1,
            pageSize: 10,
            total: 0,
          },
        },
      },
    };
  },

  computed: {
    ...mapGetters(['userInfo']),
  },
  created() {
    this.initQuery();
  },
  methods: {
    initQuery() {
      selectTenantWarehouse({ agencyId: this.userInfo.tenantId }).then((res) => {
        this.items.forEach((v) => {
          if (v.label == '盘点仓库') {
            v.options = res.map((item) => {
              item.label = item.warehouseName;
              item.value = item.id;
              return item;
            });
          }
        });
      });
      goodsModel().then((res) => {
        this.items.forEach((v) => {
          if (v.label == '规格型号') {
            v.options = res.map((item) => {
              item.label = item.modelName;
              item.value = item.id;
              return item;
            });
          }
        });
      });

    },
    showAudit(row) {
      this.editSetting.id = row.id;
      this.editSetting.info = JSON.stringify(row);
      this.editSetting.title = '编辑';
      this.editSetting.show = true;
    },
    // 查询table列表
    search(pageNum) {
      if (pageNum != undefined) {
        this.$refs.myTable.search(pageNum);
      } else {
        this.$refs.myTable.search();
      }
    },
    fifterForm(params) {
      this.filterFrom = Object.assign(this.filterFrom, params);
      this.search(1);
    },
  },
};
</script>

<style scoped></style>
